@@ -1,10 +1,5 @@
-=head1 NAME
-
-URI::Title::MP3 - get titles of MP3 files
-
-=cut
-
 package URI::Title::MP3;
+$URI::Title::MP3::VERSION = '1.900';
 use warnings;
 use strict;
 
@@ -15,7 +10,7 @@ sub types {(
   'audio/mp3',
 )}
 
-sub get_tag {
+sub _get_tag {
   my $data = shift;
   my (undef, $temp) = tempfile();
   open FILE, ">$temp" or die $!;
@@ -41,7 +36,7 @@ sub title {
     }
 
   } else {
-    $tag = get_tag( $data . URI::Title::get_end($url) );
+    $tag = _get_tag( $data . URI::Title::_get_end($url) );
   }
   return unless $tag;
   return unless ($tag->{ARTIST} or $tag->{TITLE});
@@ -60,3 +55,13 @@ sub title {
 }
 
 1;
+
+__END__
+
+=for Pod::Coverage::TrustPod types title
+
+=head1 NAME
+
+URI::Title::MP3 - get titles of MP3 files
+
+=cut
